CoilPy
======

This is Caoxiang Zhu's personal Python package for plotting and data processing.
Documentation can be found at https://zhucaoxiang.github.io/CoilPy/

Install
=======

You can install the package using `pip`.

```
pip install coilpy
```

Or from the GitHub

```
pip install git+https://github.com/zhucaoxiang/CoilPy
```

You can also install it by cloning the source code.

```
python setup.py install
```

Use
=======

After installation, in your python kernel, you can use the functions by something like
```python
from coilpy import *
```

You can always check the docstring of each functions, like `FourSurf?` in ipython.

Contact
=======

You can report bugs on `GitHub issues` and propose improvements using `pull request`.
For more information, please contact Dr. Caoxiang ZHU (caoxiangzhu[at]gmail.com).